@@ -1,5 +1,4 @@
 #!/usr/bin/env bash
-
 # Copyright (C) 2023 The Qt Company Ltd.
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
@@ -8,40 +7,44 @@ set -ex
 # Remove update notifications and packagekit running in the background
 sudo yum -y remove PackageKit gnome-software
 
-sudo yum -y update
-
 installPackages=()
 installPackages+=(git)
 installPackages+=(zlib-devel)
 installPackages+=(glib2-devel)
-installPackages+=(openssl3)
-installPackages+=(openssl3-devel)
+installPackages+=(openssl-devel)
 installPackages+=(freetype-devel)
 installPackages+=(fontconfig-devel)
 installPackages+=(curl-devel)
 installPackages+=(expat-devel)
 installPackages+=(gettext-devel)
 installPackages+=(perl-devel)
+# Required by some old pkg perl script, FindBin.pm was moved to new package in perl 5.32
+installPackages+=(perl-FindBin)
 installPackages+=(dh-autoreconf)
 # cmake build
 installPackages+=(ninja-build)
 installPackages+=(pcre2-devel)
 installPackages+=(double-conversion-devel)
 installPackages+=(zstd)
-# update kernel
-installPackages+=(kernel)
-installPackages+=(kernel-tools)
-installPackages+=(kernel-devel)
-installPackages+=(kernel-core)
-installPackages+=(kernel-modules)
-installPackages+=(kernel-headers)
 # EGL support
-# mesa-libraries need to use older version than 22.1.5-2 which cause Xorg to crash
-installPackages+=(mesa-libEGL-devel-21.3.4-1.el8)
-installPackages+=(mesa-libGL-devel-21.3.4-1.el8)
-installPackages+=(mesa-dri-drivers-21.3.4-1.el8.x86_64)
-installPackages+=(mesa-libgbm-21.3.4-1.el8.x86_64)
-installPackages+=(mesa-vulkan-drivers-21.3.4-1.el8.x86_64)
+# mesa-libEGL-devel need to use older version than 22.1.5-2.el9 which cause Xorg to crash
+#installPackages+=(mesa-libEGL-devel-21.3.4-2.el9)
+#installPackages+=(mesa-libGL-devel-21.3.4-2.el9)
+
+# Using same mesa libraries for RHEL 9.2 which also RHEL 8.8 had due to Xorg crash issue:
+#installPackages+=(mesa-libEGL-devel-21.3.4-1.el9.x86_64)
+#installPackages+=(mesa-libGL-devel-21.3.4-1.el9.x86_64)
+#installPackages+=(mesa-dri-drivers-21.3.4-1.el9.x86_64)
+#installPackages+=(mesa-libgbm-21.3.4-1.el9.x86_64)
+#installPackages+=(mesa-vulkan-drivers-21.3.4-1.el9.x86_64)
+
+# Same as lines above but with -2 version which should be found for el9
+installPackages+=(mesa-libEGL-devel-21.3.4-2.el9.x86_64)
+installPackages+=(mesa-libGL-devel-21.3.4-2.el9.x86_64)
+installPackages+=(mesa-dri-drivers-21.3.4-2.el9.x86_64)
+installPackages+=(mesa-libgbm-21.3.4-2.el9.x86_64)
+installPackages+=(mesa-vulkan-drivers-21.3.4-2.el9.x86_64)
+
 installPackages+=(libxkbfile-devel)
 # Xinput2
 installPackages+=(libXi-devel)
@@ -56,9 +59,8 @@ installPackages+=(dbus-devel)
 installPackages+=(gstreamer1-plugins-bad-free)
 installPackages+=(gstreamer1-devel)
 installPackages+=(gstreamer1-plugins-base-devel)
-# for QtMultimedia, ffmpeg
+# yasm for QtMultimedia
 installPackages+=(yasm)
-installPackages+=(libva-devel)
 # gtk3 style for QtGui/QStyle
 installPackages+=(gtk3-devel)
 # libusb1 for tqtc-boot2qt/qdb
@@ -66,13 +68,11 @@ installPackages+=(libusbx-devel)
 # speech-dispatcher-devel for QtSpeech, otherwise it has no backend on Linux
 installPackages+=(speech-dispatcher-devel)
 # Python 2 devel and pip. python-pip requires the EPEL repository to be added
-installPackages+=(python2-devel python2-pip)
+# Python 2 no longer supported
+# installPackages+=(python2-devel python2-pip)
 # Python 3 with python-devel, pip and virtualenv
-installPackages+=(python36)
-installPackages+=(python36-devel)
-# Python 3.8 for pyside. Qt for Python support for Python 3.6 will be deprecated in within pyside6.3
-installPackages+=(python38)
-installPackages+=(python38-devel)
+installPackages+=(python3)
+installPackages+=(python3-devel)
 # WebEngine
 installPackages+=(bison)
 installPackages+=(flex)
@@ -85,8 +85,9 @@ installPackages+=(libxshmfence-devel)
 installPackages+=(nspr-devel)
 installPackages+=(nss-devel)
 installPackages+=(python3-html5lib)
+installPackages+=(libstdc++-static)
 # For Android builds
-installPackages+=(java-11-openjdk-devel-11.0.19.0.7)
+installPackages+=(java-11-openjdk-devel)
 # For receiving shasum
 installPackages+=(perl-Digest-SHA)
 # INTEGRITY requirements
@@ -101,8 +102,9 @@ installPackages+=(libxslt-devel)
 # For building Wayland from source
 installPackages+=(libffi-devel)
 # QtWayland
-installPackages+=(mesa-libwayland-egl)
-installPackages+=(mesa-libwayland-egl-devel)
+# installPackages+=(mesa-libwayland-egl)
+# installPackages+=(mesa-libwayland-egl-devel)
+installPackages+=(libwayland-egl)
 installPackages+=(libwayland-client)
 installPackages+=(libwayland-cursor)
 installPackages+=(libwayland-server)
@@ -139,23 +141,27 @@ installPackages+=(gcc-c++)
 installPackages+=(make)
 # Open source VMware Tools
 installPackages+=(open-vm-tools)
+# nfs-utils is needed to make mount work with ci-files01
+installPackages+=(nfs-utils)
+
 
 sudo yum -y install "${installPackages[@]}"
 
-sudo ln -s /usr/bin/python2 /usr/bin/python
-
-sudo dnf -y module install nodejs:16
-
-sudo /usr/bin/pip3 install dataclasses
+sudo dnf install nodejs-16.14.0-4.el9_0 -y
+# Required by QtCore
+sudo dnf install 'perl(English)' -y
 
 # We shouldn't use yum to install virtualenv. The one found from package repo is not
 # working, but we can use installed pip
 sudo pip3 install --upgrade pip
 sudo pip3 install virtualenv wheel
 # Just make sure we have virtualenv to run with python3.8 -m virtualenv
-sudo python3.8 -m pip install virtualenv wheel
+sudo python -m pip install virtualenv wheel
 
 sudo /usr/bin/pip3 install wheel
 
-OpenSSLVersion="$(openssl3 version |cut -b 9-14)"
+# Make FindPython3.cmake to find python3
+sudo ln -s /usr/bin/python3 /usr/local/bin/python3
+
+OpenSSLVersion="$(openssl version |cut -b 9-14)"
 echo "OpenSSL = $OpenSSLVersion" >> ~/versions.txt
